Module: SourceFinder

Defined in:
lib/source_finder.rb,
lib/source_finder/version.rb,
lib/source_finder/langs/js.rb,
lib/source_finder/langs/ruby.rb,
lib/source_finder/langs/groovy.rb,
lib/source_finder/langs/python.rb,
lib/source_finder/option_parser.rb,
lib/source_finder/source_file_globber.rb

Overview

SourceFinder finds source and documentation files within a project.

Defined Under Namespace

Modules: GroovySourceFileGlobber, JsSourceFileGlobber, PythonSourceFileGlobber, RubySourceFileGlobber Classes: OptionParser, SourceFileGlobber

Constant Summary collapse

VERSION =

We bump the patch version when bugs are fixed; minor version when new languages or directories are added; the major version when existing APIs change

'3.2.1'.freeze